import React, { useState, useMemo } from "react";
import styles from "./CornerSwiper.module.js";
import { jsx, jsxs } from "../../_virtual/jsx-runtime.js";
const oneItem = 270;
const CornerSwiper = ({
  current,
  children,
  className = "",
  position = 0.2,
  rotateX = "0deg",
  rotateY = "-45deg",
  defaultCurrent = 0,
  defaultMargin = true,
  perspective = "1000px",
  perspectiveOriginX = "50%",
  perspectiveOriginY = "50%"
}) => {
  const [_currentIndex] = useState(defaultCurrent);
  const currentIndex = current != null ? current : _currentIndex;
  const childrenList = useMemo(() => {
    const childList = Array.isArray(children) ? children : [children];
    if (!defaultMargin) {
      return childList;
    }
    return childList.map((child) => React.cloneElement(child, {
      ...child.props,
      className: `${child.props.className || ""} mg-mr-5`
    }));
  }, [children, defaultMargin]);
  const swiperElement = /* @__PURE__ */ jsx("div", {
    className: `mg-w-full mg-h-full mg-flex-row mg-flex mg-flex-nowrap ${className}`,
    children: childrenList
  });
  const translatePercent = currentIndex / childrenList.length;
  const positionStr = `${(position + translatePercent) * 100}%`;
  const element3D = React.cloneElement(swiperElement, {
    ...swiperElement.props,
    className: `mg-absolute mg-top-0 mg-left-0 mg-overflow-hidden ${styles["element-3d"]} ${swiperElement.props.className}`,
    style: {
      "--position": positionStr,
      "--rotate-x": rotateX,
      "--rotate-y": rotateY
    }
  });
  const element2D = React.cloneElement(swiperElement, {
    ...swiperElement.props,
    className: ` mg-relative ${styles["element-2d"]} ${swiperElement.props.className}`,
    style: {
      "--position": positionStr,
      "--rotate-x": rotateX
    }
  });
  return /* @__PURE__ */ jsx("div", {
    className: `${styles["swiper-container"]}`,
    style: {
      transform: `translatex(${-translatePercent * oneItem * childrenList.length}px)`
    },
    children: /* @__PURE__ */ jsxs("div", {
      className: `mg-w-full mg-h-full mg-relative ${styles["corner-swiper"]}`,
      style: {
        perspective,
        perspectiveOrigin: `${perspectiveOriginX} ${perspectiveOriginY}`
      },
      children: [element3D, element2D]
    })
  });
};
export { CornerSwiper as default };
